==> DQScriptsDemo_0_2_1.zip: DQScriptsDemo_0_2_1/rgss-lib/dq/church/Event_Church.rb <==
#==============================================================================
#  Event_Church
#------------------------------------------------------------------------------
# Cxg
#==============================================================================

# 肠邩i
class Game_System
  attr_accessor :map_interpreter
  attr_accessor :battle_interpreter
end

module DQ

module Event_Church
  module_function
  def save
    name = $game_actors[1].name
    lv = $game_actors[1].level
    map_infos = load_data("Data/MapInfos.rxdata")

    map_id = $game_map.map_id
    comment = map_infos[map_id].name
    tmp_interpreter = $game_system.map_interpreter
    $game_system.map_interpreter = Interpreter.new(0,true)
    $game_system.battle_interpreter = Interpreter.new(0,false)

    SaveData_Facade.save($game_temp.last_file_index,name,lv,comment)

    $game_system.map_interpreter = tmp_interpreter
  end

  #--------------------------------------------------------------------------
  # Cxg쐬
  #--------------------------------------------------------------------------
  def create_event

    list = [
      '̂',
      '',
      '点',
      'ǂ̂傤',
      '̂낢Ƃ',
      '߂'
    ]

    event = Script_Event.new
    event.message("û@_ׂ̂\\n킪Ɂ@ǂȁ@pȁHv")

    event.loop_start
      event.branch_start(list,list.size)
      event.branch_item(0,save_menu)
      event.branch_item(1,next_exp_menu)
      event.branch_item(5,end_event)
      event.branch_end()
      event.message("uقɁ@ṕ@肩ȁHv")
    event.loop_end

    return event
  end
  #--------------------------------------------------------------------------
  # ICxg
  #--------------------------------------------------------------------------
  def end_event
    event = Script_Event.new
    event.message("uł́@CāB_̂́@񂱂Ƃv")
    event.event_break
#    event.brank
    return event
  end
  #--------------------------------------------------------------------------
  # Z[uj[Cxg쐬
  #--------------------------------------------------------------------------
  def save_menu
    event = Script_Event.new
    event.message("uł́@_̑O\\n܂ł́@Ȃ\\nȂv")
    event.message("uā@`̏\\nL^Ă@낵ȁHv")
    event.branch_start(['͂',''],2)
    event.branch_item(0)
      event.label('Window_SaveData_Select')
      event.message("uȂ΂́@`̏\\nL^邨肩Hv")

      event.script('$scene.message_window.fade_out_off = true')
      event.script('$w = DQ::Window_SaveData_Select.new')
      event.script('$w.interpreter')
      event.script("$scene.message_window.fade_out_off = false\ntrue")
      event.script_condition('($w.index < 0)')
        event.label_jump('No_Save')
      event.condition_end

      event.script_condition('(not $w.get_menu.nil?)')
        event.script("@tmp = @list[@index+2].parameters[0].dup")
        event.script("@list[@index+1].parameters[0][/TMP/] = $w.message_display_string")
        event.message("uTMP@\\nL^Ɂ@㏑邪\\nł@낵ȁHv")
        event.script("@list[@index-1].parameters[0] = @tmp\n@tmp = nil")
        event.branch_start(['͂',''],2)
#          event.branch_item(0)
#            event.brank
          event.branch_item(1)
            event.label_jump('Window_SaveData_Select')
        event.branch_end
      event.condition_end

      event.script("$game_temp.last_file_index = $w.index")
      event.method_call(method :save)
      event.message("uɁ@L^܂B܂@`@\\n肩Hv")
      event.add game_continue_branch

    event.branch_item(1)
      event.label('No_Save')
      event.message("uL^ȂƐ\邩B@܂@낵낤v")
    event.branch_end()
    event.message("u܂@`\\n@肩Hv")
    event.add game_continue_branch
    return event
  end
  def game_continue_branch
    event = Script_Event.new
    event.branch_start(['͂',''],2)
      event.branch_item(0,end_event)
      event.branch_item(1)
      event.message("u@_I\\n̎҂Ɂ@ЂƂƂ\\nx@܂v")
# uꂳ܂łB̂܂܁@d؂肭Bv
# ʓ|Ȃ̂ŁAƂ肠^Cg֖߂lɂĂ
      event.script("Audio.bgm_fade(800)\nAudio.bgs_fade(800)\nAudio.me_fade(800)\n$scene = ::Scene_Title.new")
    event.branch_end()
    return event
  end
  #--------------------------------------------------------------------------
  # ̌olj[Cxg쐬
  #--------------------------------------------------------------------------
  def next_exp_menu
    event = Script_Event.new
    event.message("u_̐@܂v")
    for actor in $game_party.actors
      event.message("u#{actor.name}BƁ@#{actor.next_rest_exp_s}̌o\\ñxɁ@Ȃ邶낤v")
    end
    return event
  end
end

end

==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/church/Event_Church.rb <==
#==============================================================================
#  Event_Church
#------------------------------------------------------------------------------
# Cxg
#==============================================================================

# 肠邩i
class Game_System
  attr_accessor :map_interpreter
  attr_accessor :battle_interpreter
end

module DQ

module Event_Church
  module_function
  def save
    name = $game_actors[1].name
    lv = $game_actors[1].level
    map_infos = load_data("Data/MapInfos.rxdata")

    map_id = $game_map.map_id
    comment = map_infos[map_id].name
    tmp_interpreter = $game_system.map_interpreter
    $game_system.map_interpreter = Interpreter.new(0,true)
    $game_system.battle_interpreter = Interpreter.new(0,false)

    SaveData_Facade.save($game_temp.last_file_index,name,lv,comment)

    $game_system.map_interpreter = tmp_interpreter
  end

  #--------------------------------------------------------------------------
  # Cxg쐬
  #--------------------------------------------------------------------------
  def create_event

    list = [
      '̂',
      '',
      '点',
      'ǂ̂傤',
      '̂낢Ƃ',
      '߂'
    ]

    event = Script_Event.new
    event.message("û@_ׂ̂\\n킪Ɂ@ǂȁ@pȁHv")

    event.loop_start
      event.branch_start(list,list.size)
      event.branch_item(0,save_menu)
      event.branch_item(1,next_exp_menu)
      event.branch_item(5,end_event)
      event.branch_end()
      event.message("uقɁ@ṕ@肩ȁHv")
    event.loop_end

    return event
  end
  #--------------------------------------------------------------------------
  # ICxg
  #--------------------------------------------------------------------------
  def end_event
    event = Script_Event.new
    event.message("uł́@CāB_̂́@񂱂Ƃv")
    event.event_break
#    event.brank
    return event
  end
  #--------------------------------------------------------------------------
  # Z[uj[Cxg쐬
  #--------------------------------------------------------------------------
  def save_menu
    event = Script_Event.new
    event.message("uł́@_̑O\\n܂ł́@Ȃ\\nȂv")
    event.message("uā@`̏\\nL^Ă@낵ȁHv")
    event.branch_start(['͂',''],2)
    event.branch_item(0)
      event.label('Window_SaveData_Select')
      event.message("uȂ΂́@`̏\\nL^邨肩Hv")

      event.script('$scene.message_window.fade_out_off = true')
      event.script('$w = DQ::Window_SaveData_Select.new')
      event.script('$w.interpreter')
      event.script("$scene.message_window.fade_out_off = false\ntrue")
      event.script_condition('($w.index < 0)')
        event.label_jump('No_Save')
      event.condition_end

      event.script_condition('(not $w.get_menu.nil?)')
        event.script("@tmp = @list[@index+2].parameters[0].dup")
        event.script("@list[@index+1].parameters[0][/TMP/] = $w.message_display_string")
        event.message("uTMP@\\nL^Ɂ@㏑邪\\nł@낵ȁHv")
        event.script("@list[@index-1].parameters[0] = @tmp\n@tmp = nil")
        event.branch_start(['͂',''],2)
#          event.branch_item(0)
#            event.brank
          event.branch_item(1)
            event.label_jump('Window_SaveData_Select')
        event.branch_end
      event.condition_end

      event.script("$game_temp.last_file_index = $w.index")
      event.method_call(method(:save))
      event.message("uɁ@L^܂B܂@`@\\n肩Hv")
      event.add game_continue_branch

    event.branch_item(1)
      event.label('No_Save')
      event.message("uL^ȂƐ\邩B@܂@낵낤v")
    event.branch_end()
    event.message("u܂@`\\n@肩Hv")
    event.add game_continue_branch
    return event
  end
  def game_continue_branch
    event = Script_Event.new
    event.branch_start(['͂',''],2)
      event.branch_item(0,end_event)
      event.branch_item(1)
      event.message("u@_I\\n̎҂Ɂ@ЂƂƂ\\nx@܂v")
# uꂳ܂łB̂܂܁@d؂肭Bv
# ʓ|Ȃ̂ŁAƂ肠^Cg֖߂lɂĂ
      event.script("Audio.bgm_fade(800)\nAudio.bgs_fade(800)\nAudio.me_fade(800)\n$scene = ::Scene_Title.new")
    event.branch_end()
    return event
  end
  #--------------------------------------------------------------------------
  # ̌olj[Cxg쐬
  #--------------------------------------------------------------------------
  def next_exp_menu
    event = Script_Event.new
    event.message("u_̐@܂v")
    for actor in $game_party.actors
      event.message("u#{actor.name}BƁ@#{actor.next_rest_exp_s}̌o\\ñxɁ@Ȃ邶낤v")
    end
    return event
  end
end

end
